==> auctex-emacs24-11.86_7.tbz: share/emacs/24.2/site-lisp/auctex/style/icelandic.el <==
;;; icelandic.el --- AUCTeX style for the `icelandic' babel option.

;; Copyright (C) 2007 Free Software Foundation, Inc.

;; Author: Ralf Angeli <angeli@caeruleus.net>
;; Maintainer: auctex-devel@gnu.org
;; Created: 2007-03-11
;; Keywords: tex

;; This file is part of AUCTeX.

;; AUCTeX is free software; you can redistribute it and/or modify it
;; under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 3, or (at your option)
;; any later version.

;; AUCTeX is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with AUCTeX; see the file COPYING.  If not, write to the Free
;; Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
;; 02110-1301, USA.

;;; Commentary:

;; Set up AUCTeX for editing Icelandic text in connection with the
;; `icelandic' babel option.

;;; Code:

(defvar LaTeX-icelandic-mode-syntax-table
  (copy-syntax-table LaTeX-mode-syntax-table)
  "Syntax table used in LaTeX mode when using `icelandic.sty'.")

(modify-syntax-entry ?\" "w" LaTeX-icelandic-mode-syntax-table)

(TeX-add-style-hook
 "icelandic"
 (lambda ()
   (set-syntax-table LaTeX-icelandic-mode-syntax-table)
   (setq TeX-quote-language '("icelandic" "\"`" "\"'" t))
   (setq LaTeX-babel-hyphen-language "icelandic")
   ;; Fontification of quotation marks.
   (when (fboundp 'font-latex-add-quotes)
     (font-latex-add-quotes '("\"`" "\"'"))
     (font-latex-add-quotes '("\"<" "\">" french)))
   (run-hooks 'TeX-language-is-hook)))

;;; icelandic.el ends here

==> auctex-emacs24-11.87_1.tbz: share/emacs/24.3/site-lisp/auctex/style/icelandic.el <==
;;; icelandic.el --- AUCTeX style for the `icelandic' babel option.

;; Copyright (C) 2007 Free Software Foundation, Inc.

;; Author: Ralf Angeli <angeli@caeruleus.net>
;; Maintainer: auctex-devel@gnu.org
;; Created: 2007-03-11
;; Keywords: tex

;; This file is part of AUCTeX.

;; AUCTeX is free software; you can redistribute it and/or modify it
;; under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 3, or (at your option)
;; any later version.

;; AUCTeX is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with AUCTeX; see the file COPYING.  If not, write to the Free
;; Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
;; 02110-1301, USA.

;;; Commentary:

;; Set up AUCTeX for editing Icelandic text in connection with the
;; `icelandic' babel option.

;;; Code:

(defvar LaTeX-icelandic-mode-syntax-table
  (copy-syntax-table LaTeX-mode-syntax-table)
  "Syntax table used in LaTeX mode when using `icelandic.sty'.")

(modify-syntax-entry ?\" "w" LaTeX-icelandic-mode-syntax-table)

(TeX-add-style-hook
 "icelandic"
 (lambda ()
   (set-syntax-table LaTeX-icelandic-mode-syntax-table)
   (unless (eq (car TeX-quote-language) 'override)
     (setq TeX-quote-language '("icelandic" "\"`" "\"'" t)))
   (setq LaTeX-babel-hyphen-language "icelandic")
   ;; Fontification of quotation marks.
   (when (fboundp 'font-latex-add-quotes)
     (font-latex-add-quotes '("\"`" "\"'"))
     (font-latex-add-quotes '("\"<" "\">" french)))
   (run-hooks 'TeX-language-is-hook)))

;;; icelandic.el ends here
